/*
 * Project:        Exercise 10.1
 * File:           properties.cxx
 * Author:         Kevin Kroeninger
 * Version (date): 1.0 (21.06.2013)
 *
 * Copyright (C) 2013, Kevin Kroeninger
 * All rights reserved.
 *
 * Description:
 * A simple ROOT macro which calculates the properties of an
 * estimator. The macro can be used in CINT.
 *
 * This code is distributed with the solution manual to the book
 *
 * Data Analysis in High Energy Physics: A Practical Guide to Statistical Methods,
 * Wiley-VCH (2013),
 * O. Behnke, K. Kroeninger, G. Schott, Th. Schorrner-Sadenius (editors)
 */

void properties()
{
  // initialize random number generator
  gRandom = new TRandom3(1001);
	
  // define settings
  int nevents    = 10; // or 100
  int nensembles = 100000;
	
  // define histograms
  TH1D* hist_mean      = new TH1D("hist_mean", ";#bar{x};N", 1000, 0.0, 1.0);
  TH1D* hist_variance1 = new TH1D("hist_variance1", ";s'^{2};N", 1000, 0.0, 0.25);
  TH1D* hist_variance2 = new TH1D("hist_variance2", ";s^{2};N", 1000, 0.0, 0.25);
	
  // loop over all ensembles
  for (int i = 0; i < nensembles; ++i) {
    double sum = 0;
    double sum2 = 0;
		
    // generate random numbers
    for (int j = 0; j < nevents; ++j) {
      double x = gRandom->Uniform();
			
      // calculate sum and sum of squares
      sum += x;
      sum2 += x*x;
    }
    
    // calculate mean value and variances with and without Bessel correction
    double mean      = sum/double(nevents);
    double variance1 = sum2/double(nevents)   - sum*sum/double(nevents*nevents);
    double variance2 = sum2/double(nevents-1) - sum*sum/double(nevents*(nevents-1));
		
    // fill mean value and variances into histograms    
    hist_mean->Fill(mean);
    hist_variance1->Fill(variance1);
    hist_variance2->Fill(variance2);
  }
	
  // draw histograms
  TCanvas* c1 = new TCanvas("c1", "", 900, 300);
  c1->Divide(3, 1);
  c1->cd(1);
  hist_mean->Draw();
  c1->cd(2);
  hist_variance1->Draw();
  c1->cd(3);
  hist_variance2->Draw();
	
  // print results to screen
  std::cout << "True values: " << std::endl;
  std::cout << " mean     = 0.5 " << std::endl;
  std::cout << " variance = " << 1./12. << std::endl;
  std::cout << std::endl;
  
  std::cout << "Estimated values: " << std::endl;
  std::cout << " mean     = " << hist_mean->GetMean() << " +- " << hist_mean->GetMeanError() << std::endl;
  std::cout << " variance = " << hist_variance1->GetMean() << " +- " << hist_variance1->GetMeanError() << " (without Bessel correction)" << std::endl;
  std::cout << " variance = " << hist_variance2->GetMean() << " +- " << hist_variance2->GetMeanError() << " (with Bessel correction)" << std::endl;
  std::cout << std::endl;
}
  
