/*
 * Project:        Exercise 10.2
 * File:           PoissonModel.h
 * Author:         Kevin Kroeninger
 * Version (date): 1.0 (21.06.2013)
 *
 * Copyright (C) 2013, Kevin Kroeninger
 * All rights reserved.
 *
 * Description:
 * A counting model formulated in BAT version 0.9.2. BAT must be
 * installed. The code has to be compiled. 
 *
 * This code is distributed with the solution manual to the book
 *
 * Data Analysis in High Energy Physics: A Practical Guide to Statistical Methods,
 * Wiley-VCH (2013),
 * O. Behnke, K. Kroeninger, G. Schott, Th. Schorrner-Sadenius (editors)
 */

#ifndef __POISSONMODEL__H
#define __POISSONMODEL__H

#include <BAT/BCModel.h>

// ---------------------------------------------------------
class PoissonModel : public BCModel
{
 public:

  // Constructors and destructor
  PoissonModel();
  ~PoissonModel();

  // set number of observed events
  int SetNObs(int nobs, double nu_bkg = 0);

  // get number of observed events
  int GetNObs()
  { return fNObs; };

  // Methods to overload, see file PoissonModel.cxx
  void DefineParameters();
  //      double LogAPrioriProbability(const std::vector<double> &parameters);
  double LogLikelihood(const std::vector<double> &parameters);

 private:
  // number of observed events
  int fNObs;

  // number of expected background events
  double fNuBkg;
};
// ---------------------------------------------------------

#endif

