/*
 * Project:        Exercise 10.3
 * File:           Template.cxx
 * Author:         Kevin Kroeninger
 * Version (date): 1.0 (21.06.2013)
 *
 * Copyright (C) 2013, Kevin Kroeninger
 * All rights reserved.
 *
 * Description:
 * A template fit to the data formulated in BAT version 0.9.2. BAT must
 * be installed. The code has to be compiled.
 *
 * This code is distributed with the solution manual to the book
 *
 * Data Analysis in High Energy Physics: A Practical Guide to Statistical Methods,
 * Wiley-VCH (2013),
 * O. Behnke, K. Kroeninger, G. Schott, Th. Schorrner-Sadenius (editors)
 */

#include "Template.h"

#include <BAT/BCMath.h>

// ---------------------------------------------------------
Template::Template() : BCModel()
                     , fHistData(0)
                     , fHistSignal(0)
                     , fHistBackground(0)
{
  // default constructor
  DefineParameters();
}

// ---------------------------------------------------------
Template::Template(const char * name) : BCModel(name)
{
  // constructor
  DefineParameters();
}

// ---------------------------------------------------------
Template::~Template()
// default destructor
{
}

// ---------------------------------------------------------
void Template::DefineParameters()
{
  AddParameter("S", 0.,   40.); // index 0
  AddParameter("B", 40., 100.); // index 1
}

// ---------------------------------------------------------
double Template::LogLikelihood(const std::vector<double> &parameters)
{
  double logprob = 0.;

  double s = parameters.at(0);
  double b = parameters.at(1);

  int nbins = fHistData->GetNbinsX();

  for (int i = 1; i <= nbins; ++i) {

    double obs = fHistData->GetBinContent(i);
    double exp_s = s*fHistSignal->GetBinContent(i);
    double exp_b = b*fHistBackground->GetBinContent(i);
    double exp_sum = exp_s+exp_b;

    if (fLHOption == 0)
      logprob += BCMath::LogPoisson(obs, exp_sum);
    if (fLHOption == 1)
      logprob += BCMath::LogGaus(obs, exp_sum, sqrt(exp_sum));
    if (fLHOption == 2)
      if (obs!=0)
        logprob += BCMath::LogGaus(obs, exp_sum, sqrt(obs));
  }
   
  return logprob;
}

// ---------------------------------------------------------
double Template::LogAPrioriProbability(const std::vector<double> &parameters)
{
  double logprob = 0.;

  double b = parameters.at(1);
  logprob += BCMath::LogGaus(b, fBkgExp, 0.1*fBkgExp);   // Gaussian prior for y

  return logprob;
}
// ---------------------------------------------------------

