/*
 * Project:        Exercise 10.3
 * File:           Template.h
 * Author:         Kevin Kroeninger
 * Version (date): 1.0 (21.06.2013)
 *
 * Copyright (C) 2013, Kevin Kroeninger
 * All rights reserved.
 *
 * Description:
 * A template fit to the data formulated in BAT version 0.9.2. BAT must
 * be installed. The code has to be compiled.
 *
 * This code is distributed with the solution manual to the book
 *
 * Data Analysis in High Energy Physics: A Practical Guide to Statistical Methods,
 * Wiley-VCH (2013),
 * O. Behnke, K. Kroeninger, G. Schott, Th. Schorrner-Sadenius (editors)
 */

#ifndef __BAT__TEMPLATE__H
#define __BAT__TEMPLATE__H

#include <TH1D.h>

#include <BAT/BCModel.h>

// ---------------------------------------------------------
class Template : public BCModel
{
 public:

  // Constructors and destructor
  Template();
  Template(const char * name);
  ~Template();

  void SetData(TH1D* hist)
  { fHistData = new TH1D(*hist); };

  void SetSignal(TH1D* hist)
  { fHistSignal = new TH1D(*hist); };

  void SetBackground(TH1D* hist)
  { fHistBackground = new TH1D(*hist); };

  void SetLHOption(int option)
  { fLHOption = option; };

  void SetBkg(double n)
  { fBkgExp = n; };

  // Methods to overload, see file Template.cxx
  void DefineParameters();
  double LogAPrioriProbability(const std::vector<double> &parameters);
  double LogLikelihood(const std::vector<double> &parameters);

  TH1D* fHistData; 
  TH1D* fHistSignal; 
  TH1D* fHistBackground; 
  double fBkgExp;
  int fLHOption;
};
// ---------------------------------------------------------

#endif

